summaryrefslogtreecommitdiffstats
path: root/chrome/browser/browser.h
diff options
context:
space:
mode:
authorben@chromium.org <ben@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2009-02-02 06:42:05 +0000
committerben@chromium.org <ben@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2009-02-02 06:42:05 +0000
commit0303f31c7e78cd5e1e54773c50b9216710630cfa (patch)
tree86a23bd959f744152f1bfe3a1ad91e965994a0d1 /chrome/browser/browser.h
parent0b7c092f7f5b196fd9085f1ab796a0c9ac9473a6 (diff)
downloadchromium_src-0303f31c7e78cd5e1e54773c50b9216710630cfa.zip
chromium_src-0303f31c7e78cd5e1e54773c50b9216710630cfa.tar.gz
chromium_src-0303f31c7e78cd5e1e54773c50b9216710630cfa.tar.bz2
Remove old web app code it's no longer needed. Simplifies startup a little.
Also fixes a regression from the BrowserInit porting work. I was a little over-zealous removing the CommandLine handling. It turns out that it's this that MessageWindow uses to convey the command line of the signalling process to the existing process, and that the existing process re-runs BrowserInit with the signalling process' command line. So I plumbed that back through again. Review URL: http://codereview.chromium.org/19746 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@9034 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/browser/browser.h')
-rw-r--r--chrome/browser/browser.h16
1 files changed, 4 insertions, 12 deletions
diff --git a/chrome/browser/browser.h b/chrome/browser/browser.h
index 8286cf23..ce81f5c 100644
--- a/chrome/browser/browser.h
+++ b/chrome/browser/browser.h
@@ -42,7 +42,6 @@ class PrefService;
class Profile;
class StatusBubble;
class TabNavigation;
-class WebApp;
class Browser : public TabStripModelDelegate,
public TabStripModelObserver,
@@ -124,8 +123,8 @@ class Browser : public TabStripModelDelegate,
// |profile|, that session is re-used.
static void OpenURLOffTheRecord(Profile* profile, const GURL& url);
- // Opens the a new application window for the specified WebApp.
- static void OpenWebApplication(Profile* profile, WebApp* app);
+ // Opens the a new application ("thin frame") window for the specified url.
+ static void OpenApplicationWindow(Profile* profile, const GURL& url);
// State Storage and Retrieval for UI ///////////////////////////////////////
@@ -192,13 +191,6 @@ class Browser : public TabStripModelDelegate,
PageTransition::Type transition, bool foreground,
SiteInstance* instance);
- // Add a new application tab for the specified URL. If lazy is true, the tab
- // won't be selected. Further, the initial web page load will only take place
- // when the tab is first selected.
- TabContents* AddWebApplicationTab(Profile* profile,
- WebApp* web_app,
- bool lazy);
-
// Add a new tab, given a NavigationController. A TabContents appropriate to
// display the last committed entry is created and returned.
TabContents* AddTabWithNavigationController(NavigationController* ctrl,
@@ -537,6 +529,8 @@ class Browser : public TabStripModelDelegate,
// after a return to the message loop.
void CloseFrame();
+#endif // OS_WIN
+
// Compute a deterministic name based on the URL. We use this pseudo name
// as a key to store window location per application URLs.
static std::wstring ComputeApplicationNameFromURL(const GURL& url);
@@ -545,8 +539,6 @@ class Browser : public TabStripModelDelegate,
// done only once per application name / per session.
static void RegisterAppPrefs(const std::wstring& app_name);
-#endif // OS_WIN
-
// Data members /////////////////////////////////////////////////////////////
// This Browser's type.